from distutils.core import setup

setup(
    name            = 'pg_37',
    version         = '1.0.0',
    py_modules      = ['pg_37'],
    author          = 'rafaelmcouto',
    author_mail     = 'rafaelmcouto@gmail.com',
    url             = '',
    description     = 'A simple printer of nester lists'
)
